.. currentmodule:: erppeek

Introduction
============

This section gives the bare minimum to use ERPpeek as a :ref:`command line
tool <command-line>` or within an :ref:`interactive shell <interactive-mode>`.

Installation
------------

Download and install the `latest release
<http://pypi.python.org/pypi/ERPpeek>`__ from PyPI::

    pip install -U erppeek


.. _command-line:

.. include:: ../README.rst
   :start-after: _command-line:

More details in the :doc:`tutorial` section.
